# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tunnel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tunnel.proto',
  package='tunnel_api',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0ctunnel.proto\x12\ntunnel_api\"\x99\x01\n\x04Node\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12-\n\x0c\x63hannel_type\x18\x02 \x01(\x0e\x32\x17.tunnel_api.ChannelType\x12\x1e\n\x04role\x18\x03 \x01(\x0e\x32\x10.tunnel_api.Role\x12\x0c\n\x04name\x18\x04 \x01(\t\x12$\n\x07service\x18\x05 \x01(\x0e\x32\x13.tunnel_api.Service\"\x8b\x01\n\x06Result\x12\x32\n\x0bresult_code\x18\x01 \x01(\x0e\x32\x1d.tunnel_api.Result.ResultType\"M\n\nResultType\x12\x06\n\x02OK\x10\x00\x12\x11\n\rUNKNOWN_ERROR\x10\x01\x12\x11\n\rNOT_AVAILABLE\x10\x02\x12\x11\n\rMESSAGE_ERROR\x10\x03*1\n\x0b\x43hannelType\x12\x0b\n\x07REQ_RES\x10\x00\x12\x15\n\x11PUBLISH_SUBSCRIBE\x10\x01*%\n\x07Service\x12\t\n\x05STOCK\x10\x00\x12\x0f\n\x0bSTOCK_ORDER\x10\x01* \n\x04Role\x12\n\n\x06\x43LIENT\x10\x00\x12\x0c\n\x08PROVIDER\x10\x01\x62\x06proto3'
)

_CHANNELTYPE = _descriptor.EnumDescriptor(
  name='ChannelType',
  full_name='tunnel_api.ChannelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQ_RES', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLISH_SUBSCRIBE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=326,
  serialized_end=375,
)
_sym_db.RegisterEnumDescriptor(_CHANNELTYPE)

ChannelType = enum_type_wrapper.EnumTypeWrapper(_CHANNELTYPE)
_SERVICE = _descriptor.EnumDescriptor(
  name='Service',
  full_name='tunnel_api.Service',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK_ORDER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=377,
  serialized_end=414,
)
_sym_db.RegisterEnumDescriptor(_SERVICE)

Service = enum_type_wrapper.EnumTypeWrapper(_SERVICE)
_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='tunnel_api.Role',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLIENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVIDER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=416,
  serialized_end=448,
)
_sym_db.RegisterEnumDescriptor(_ROLE)

Role = enum_type_wrapper.EnumTypeWrapper(_ROLE)
REQ_RES = 0
PUBLISH_SUBSCRIBE = 1
STOCK = 0
STOCK_ORDER = 1
CLIENT = 0
PROVIDER = 1


_RESULT_RESULTTYPE = _descriptor.EnumDescriptor(
  name='ResultType',
  full_name='tunnel_api.Result.ResultType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_AVAILABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MESSAGE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=247,
  serialized_end=324,
)
_sym_db.RegisterEnumDescriptor(_RESULT_RESULTTYPE)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='tunnel_api.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='tunnel_api.Node.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='tunnel_api.Node.channel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='tunnel_api.Node.role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='tunnel_api.Node.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='tunnel_api.Node.service', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=182,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='tunnel_api.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_code', full_name='tunnel_api.Result.result_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESULT_RESULTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=324,
)

_NODE.fields_by_name['channel_type'].enum_type = _CHANNELTYPE
_NODE.fields_by_name['role'].enum_type = _ROLE
_NODE.fields_by_name['service'].enum_type = _SERVICE
_RESULT.fields_by_name['result_code'].enum_type = _RESULT_RESULTTYPE
_RESULT_RESULTTYPE.containing_type = _RESULT
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.enum_types_by_name['ChannelType'] = _CHANNELTYPE
DESCRIPTOR.enum_types_by_name['Service'] = _SERVICE
DESCRIPTOR.enum_types_by_name['Role'] = _ROLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'tunnel_pb2'
  # @@protoc_insertion_point(class_scope:tunnel_api.Node)
  })
_sym_db.RegisterMessage(Node)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'tunnel_pb2'
  # @@protoc_insertion_point(class_scope:tunnel_api.Result)
  })
_sym_db.RegisterMessage(Result)


# @@protoc_insertion_point(module_scope)
