# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock.proto',
  package='stock_api',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bstock.proto\x12\tstock_api\x1a\x1fgoogle/protobuf/timestamp.proto\"\x84\x01\n\rStockDayQuery\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x31\n\rfrom_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0euntil_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"d\n\nStockQuery\x12\x0e\n\x06uuid_h\x18\x01 \x01(\x04\x12\x0e\n\x06uuid_l\x18\x02 \x01(\x04\x12-\n\tday_query\x18\x03 \x01(\x0b\x32\x18.stock_api.StockDayQueryH\x00\x42\x07\n\x05query\"R\n\x0bStockResult\x12\x0e\n\x06uuid_h\x18\x01 \x01(\x04\x12\x0e\n\x06uuid_l\x18\x02 \x01(\x04\x12#\n\x04\x63ode\x18\x03 \x01(\x0e\x32\x15.stock_api.ResultCode*;\n\nResultCode\x12\x06\n\x02OK\x10\x00\x12\x0f\n\x0bNO_PROVIDER\x10\x01\x12\x14\n\x10RESPONSE_TIMEOUT\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_RESULTCODE = _descriptor.EnumDescriptor(
  name='ResultCode',
  full_name='stock_api.ResultCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_PROVIDER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=380,
  serialized_end=439,
)
_sym_db.RegisterEnumDescriptor(_RESULTCODE)

ResultCode = enum_type_wrapper.EnumTypeWrapper(_RESULTCODE)
OK = 0
NO_PROVIDER = 1
RESPONSE_TIMEOUT = 2



_STOCKDAYQUERY = _descriptor.Descriptor(
  name='StockDayQuery',
  full_name='stock_api.StockDayQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='stock_api.StockDayQuery.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_datetime', full_name='stock_api.StockDayQuery.from_datetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='until_datetime', full_name='stock_api.StockDayQuery.until_datetime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=192,
)


_STOCKQUERY = _descriptor.Descriptor(
  name='StockQuery',
  full_name='stock_api.StockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid_h', full_name='stock_api.StockQuery.uuid_h', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid_l', full_name='stock_api.StockQuery.uuid_l', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day_query', full_name='stock_api.StockQuery.day_query', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='stock_api.StockQuery.query',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=194,
  serialized_end=294,
)


_STOCKRESULT = _descriptor.Descriptor(
  name='StockResult',
  full_name='stock_api.StockResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid_h', full_name='stock_api.StockResult.uuid_h', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid_l', full_name='stock_api.StockResult.uuid_l', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='stock_api.StockResult.code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=378,
)

_STOCKDAYQUERY.fields_by_name['from_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STOCKDAYQUERY.fields_by_name['until_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STOCKQUERY.fields_by_name['day_query'].message_type = _STOCKDAYQUERY
_STOCKQUERY.oneofs_by_name['query'].fields.append(
  _STOCKQUERY.fields_by_name['day_query'])
_STOCKQUERY.fields_by_name['day_query'].containing_oneof = _STOCKQUERY.oneofs_by_name['query']
_STOCKRESULT.fields_by_name['code'].enum_type = _RESULTCODE
DESCRIPTOR.message_types_by_name['StockDayQuery'] = _STOCKDAYQUERY
DESCRIPTOR.message_types_by_name['StockQuery'] = _STOCKQUERY
DESCRIPTOR.message_types_by_name['StockResult'] = _STOCKRESULT
DESCRIPTOR.enum_types_by_name['ResultCode'] = _RESULTCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StockDayQuery = _reflection.GeneratedProtocolMessageType('StockDayQuery', (_message.Message,), {
  'DESCRIPTOR' : _STOCKDAYQUERY,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:stock_api.StockDayQuery)
  })
_sym_db.RegisterMessage(StockDayQuery)

StockQuery = _reflection.GeneratedProtocolMessageType('StockQuery', (_message.Message,), {
  'DESCRIPTOR' : _STOCKQUERY,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:stock_api.StockQuery)
  })
_sym_db.RegisterMessage(StockQuery)

StockResult = _reflection.GeneratedProtocolMessageType('StockResult', (_message.Message,), {
  'DESCRIPTOR' : _STOCKRESULT,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:stock_api.StockResult)
  })
_sym_db.RegisterMessage(StockResult)


# @@protoc_insertion_point(module_scope)
